﻿using System.Collections.Generic;

namespace GcPdfViewerSupportApi.Models
{

    /// <summary>
    /// Information about document modifications.
    /// </summary>
    public class DocumentModifications
    {

        /// <summary>
        /// Document rotation.
        /// </summary>
        public int? rotation { get; set; }

        /// <summary>
        /// Not used.
        /// </summary>
        public bool? renderInteractiveForms { get; set; }

        /// <summary>
        /// Acro-form data. Key - page index, value, form fields data.
        /// </summary>
        public Dictionary<string, Dictionary<string, string[]>> formData { get; set; }

        /// <summary>
        /// Annotations data.
        /// </summary>
        public AnnotationsState annotationsData { get; set; }

        /// <summary>
        /// Information about document structure changes.
        /// </summary>
        public List<StructureChange> structureChanges { get; set; }

        /// <summary>
        /// Annotations order.
        /// </summary>
        public Dictionary<int, string[]> annotationsOrderTable { get; set; }

    }

    /// <summary>
    /// Annotation info.
    /// </summary>
    public class AnnotationInfo
    {
        public int pageIndex;
        public Dictionary<string, dynamic> annotation;
    }

    /// <summary>
    /// Annotation info.
    /// </summary>
    public class RemovedAnnotationInfo
    {
        public int pageIndex;
        public string annotationId;
    }

    /// <summary>
    /// Annotations data.
    /// </summary>
    public class AnnotationsState
    {
        public IList<AnnotationInfo> newAnnotations { get; set; }

        public IList<AnnotationInfo> updatedAnnotations { get; set; }
        
        public IList<RemovedAnnotationInfo> removedAnnotations { get; set; }

    }

    /// <summary>
    /// Document structure modifications.
    /// </summary>
    public class StructureChange
    {
        /// <summary>
        /// Changed page index.
        /// </summary>
        public int pageIndex { get; set; }
        /// <summary>
        /// true - page added, false - page removed
        /// </summary>
        public bool add { get; set; }

        /// <summary>
        /// Pages count before change.
        /// </summary>
        public int checkNumPages { get; set; }

    }

}
