import './themes/default.scss';
import { i18n } from 'i18next';
//@ts-ignore
import { ToolbarLayout, ZoomMode } from '@grapecity/viewer-core';
import PdfReportPlugin, { ErrorEventArgs, BeforeOpenEventArgs, AfterOpenEventArgs } from './plugin';
import { ViewerOptions } from './ViewerOptions';
//@ts-ignore
import { ReportViewer, LoadResult, EventFan } from '@grapecity/viewer-core';
import { ISupportApi } from './SupportApi/ISupportApi';
import { GcPdfViewerToolbarLayout } from './GcPdfViewerToolbarLayout';
import { AnnotationBase, CopyBufferData } from './Annotations/AnnotationTypes';
import { EditMode, LayoutMode } from './Annotations/types';
import { GcSelectionPoint } from './Models/GcMeasurementTypes';
import { GcRightSidebarState } from './RightSidebar/types';
import { GcRightSidebar } from './RightSidebar/GcRightSidebar';
export declare class GcPdfViewer extends ReportViewer {
    private static _i18n;
    private _plugin;
    private _isUpdating;
    private _toolbarLayout;
    readonly in17n: i18n;
    constructor(element: HTMLElement | string, options?: Partial<ViewerOptions>);
    get fileData(): Uint8Array | null;
    get fileName(): string;
    get fileUrl(): string;
    get plugin(): PdfReportPlugin;
    get options(): Partial<ViewerOptions>;
    set options(options: Partial<ViewerOptions>);
    get hideAnnotations(): boolean;
    set hideAnnotations(hide: boolean);
    get version(): string;
    get supportApi(): ISupportApi | null;
    get editMode(): EditMode;
    set editMode(mode: EditMode);
    get layoutMode(): LayoutMode;
    set layoutMode(mode: LayoutMode);
    get hasCopyData(): boolean;
    get rotation(): number;
    set rotation(degrees: number);
    get hasDocument(): boolean;
    get hasChanges(): boolean;
    get canEditDocument(): boolean;
    get toolbarLayout(): GcPdfViewerToolbarLayout;
    set toolbarLayout(toolbarLayout: GcPdfViewerToolbarLayout);
    get currentUserName(): string;
    set currentUserName(userName: string);
    get hasReplyTool(): boolean;
    get rightSidebar(): GcRightSidebar;
    get fingerprint(): string;
    static get i18n(): i18n;
    get annotations(): Promise<{
        pageIndex: number;
        annotations: AnnotationBase[];
    }[]>;
    get beforeUnloadConfirmation(): boolean;
    set beforeUnloadConfirmation(enable: boolean);
    get hasUndoChanges(): boolean;
    get hasRedoChanges(): boolean;
    get undoIndex(): number;
    get undoCount(): number;
    get pageIndex(): number;
    set pageIndex(val: number);
    get pageCount(): number;
    set zoomValue(val: number);
    get zoomValue(): number;
    set zoomMode(val: ZoomMode);
    get zoomMode(): ZoomMode;
    get onError(): EventFan<ErrorEventArgs>;
    get onBeforeOpen(): EventFan<BeforeOpenEventArgs>;
    get onAfterOpen(): EventFan<AfterOpenEventArgs>;
    open(file: any): Promise<LoadResult>;
    openLocalFile(): any;
    newDocument(params?: {
        fileName?: string;
        confirm?: boolean;
    }): Promise<LoadResult | null>;
    newPage(params?: {
        width?: number;
        height?: number;
        pageIndex?: number;
    }): void;
    deletePage(pageIndex?: number): void;
    print(): void;
    download(fileName?: string): void;
    save(fileName?: string): Promise<boolean>;
    saveChanges(): Promise<boolean>;
    submitForm(submitUrl: string): void;
    goToPageNumber(pageNumber: number): void;
    goToFirstPage(): void;
    goToPrevPage(): void;
    goToNextPage(): void;
    goToLastPage(): void;
    scrollPageIntoView(params: {
        pageNumber: number;
        destArray?: any[];
        allowNegativeOffset?: boolean;
    }): void;
    loadAndScrollPageIntoView(pageIndex: number, destArray?: any[]): Promise<boolean>;
    setTheme(theme?: string): void;
    execCutAction(buffer?: CopyBufferData): Promise<boolean>;
    execCopyAction(buffer?: CopyBufferData): Promise<boolean>;
    execDeleteAction(buffer?: CopyBufferData): Promise<boolean>;
    execPasteAction(point?: GcSelectionPoint): Promise<boolean>;
    loadDocumentList(): void;
    addDefaultPanels(): void;
    addDocumentListPanel(): void;
    addThumbnailsPanel(): void;
    addSearchPanel(): void;
    addAnnotationEditorPanel(): void;
    addArticlesPanel(): void;
    addAttachmentsPanel(): void;
    addOutlinePanel(): void;
    addReplyTool(sidebarState?: GcRightSidebarState): void;
    addFormEditorPanel(): void;
    cloneAnnotation(annotation: AnnotationBase): AnnotationBase;
    getSelectedText(): string;
    toViewPortPoint(point: GcSelectionPoint): GcSelectionPoint;
    addStickyNote(position: GcSelectionPoint): void;
    changeBoundsOrigin(pageIndex: number, bounds: number[], srcOrigin: 'TopLeft' | 'BottomLeft', destOrigin: 'TopLeft' | 'BottomLeft'): number[];
    getViewPort(pageIndex: number): {
        viewBox: number[];
        width: number;
        height: number;
        scale: number;
        rotation: number;
    };
    addAnnotation(pageIndex: number, annotation: AnnotationBase): Promise<{
        pageIndex: number;
        annotation: AnnotationBase;
    }>;
    updateAnnotation(pageIndex: number, annotation: AnnotationBase): Promise<{
        pageIndex: number;
        annotation: AnnotationBase;
    }>;
    updateAnnotations(pageIndex: number, annotations: AnnotationBase | AnnotationBase[]): Promise<{
        pageIndex: number;
        annotations: AnnotationBase[];
    }>;
    updateRadioGroupValue(fieldName: string, newValue: string, skipPageRefresh?: boolean): Promise<boolean>;
    removeAnnotation(pageIndex: number, annotationId: string): Promise<boolean>;
    findAnnotation(findString: string, findParams?: {
        findField?: 'id' | 'title' | 'contents' | 'fieldName' | string;
        pageNumberConstraint?: number;
        findAll?: boolean;
    }): Promise<{
        pageNumber: number;
        annotation: AnnotationBase;
    }[]>;
    selectAnnotation(pageIndex: number | string, annotation?: AnnotationBase | string): Promise<boolean>;
    unselectAnnotation(): any;
    scrollAnnotationIntoView(pageIndex: number, annotation: AnnotationBase): any;
    undoChanges(): void;
    redoChanges(): void;
    repaint(): void;
    applyOptions(): void;
    applyToolbarLayout(): void;
    enablePdfToolButtons(buttons?: string[] | "all" | 'none'): void;
    updateLayout(layout: ToolbarLayout): void;
    goBack(): void;
    goForward(): void;
    beginUpdate(): void;
    endUpdate(): void;
    get isUpdating(): boolean;
    private static _init_i18n;
}
export default GcPdfViewer;
