//@ts-ignore
import { PluginModel, DocumentMoniker, SearchFeature, ToolbarItem, Model, LoadResult, Store, EventFan } from '@grapecity/viewer-core';
import { ContextMenuProvider } from "@grapecity/core-ui-react";
import * as Articles from './Articles';
import { ParameterInfo, InteractivityAction, DrillthroughAction } from './GcPdfDocument';
import { GcPdfSearcher } from './Search/GcPdfSearcher';
import { GcPdfPasswordDialog } from './Password/GcPdfPasswordDialog';
import { ConfirmationDialog } from './Dialogs/ConfirmationDialog';
import { ViewerOptions } from './ViewerOptions';
import { GcPdfViewer } from './GcPdfViewer';
import { ArticleBead } from './Articles/types';
import { GcPdfViewerStateStorage } from './GcPdfViewerStateStorage';
import { ShortcutsConfig } from './Keyboard/ShortcutsConfig';
import { DocumentProperties } from './Properties/DocumentProperties';
import { DocumentSecuritySummary } from './Security/DocumentSecuritySummary';
import { ISupportApi } from './SupportApi/ISupportApi';
import { LayoutMode, EditMode } from './Annotations/types';
import { AnnotationBase, TextAnnotation, AnnotationMarkedStateType, AnnotationReviewStateType, CopyBufferData } from './Annotations/AnnotationTypes';
import { ProgressDialog } from './Dialogs/ProgressDialog';
import { i18n } from 'i18next';
import { GcSelectionPoint } from './Models/GcMeasurementTypes';
import { GcRightSidebar } from './RightSidebar/GcRightSidebar';
import { ReplyToolModel } from './ReplyTool/types';
import { GcEditableTextBehavior } from './Utils/GcEditableTextBehavior';
import { GcRightSidebarState } from './RightSidebar/types';
declare type ReportEvent = PluginModel.ViewerEvent | {
    type: "ItemClicked";
    iStorePos: number;
    a: InteractivityAction;
};
declare type ReportAction = InteractivityAction | DrillthroughAction | {
    Type: "print";
} | {
    Type: "download";
} | {
    Type: "save";
} | {
    Type: "rotate";
} | {
    Type: "text-selection";
} | {
    Type: "pan";
} | {
    Type: "doc-properties";
};
export declare class ReportDocumentMoniker implements DocumentMoniker {
    readonly uri: string;
    readonly params: ParameterInfo[];
    readonly pluginKey = "pdf";
    constructor(uri: string, params: ParameterInfo[]);
}
export declare type ErrorEventArgs = {
    readonly message: string;
    readonly source: GcPdfViewer;
    readonly type: 'open' | string;
    readonly exception?: any;
};
export declare type BeforeOpenEventArgs = {
    readonly payload: Uint8Array | string;
    readonly type: 'binary' | 'url';
    readonly source: GcPdfViewer;
};
export declare type AfterOpenEventArgs = {
    readonly source: GcPdfViewer;
};
export declare class PdfReportPlugin implements PluginModel.IPluginModule<ReportEvent, ReportAction> {
    readonly _viewer: GcPdfViewer;
    readonly pluginKey = "pdf";
    in17n: i18n;
    private readonly _httpClient;
    private _searcher;
    private _attachmentsPanel?;
    private _articlesPanel?;
    private _contentsPanel?;
    private _thumbnailsPanel?;
    private _searchPanel?;
    private _searchPanelRef?;
    private _annotationsPanel?;
    private _acroFormPanel?;
    private _pinchZoomGesture;
    private _shortcutsConfig;
    private _document;
    private _lastViewerState;
    private _titleToolbarItem;
    private _titleToolbarItemRemoved;
    private readonly _errorEvent;
    private readonly _beforeOpenEvent;
    private readonly _afterOpenEvent;
    _options: ViewerOptions;
    _documentTitle: string;
    _outlineStore: Store<any, any> | null;
    _articlesStore: Store<any, any> | null;
    _attachmentsStore: Store<any, any> | null;
    _annotationsStore: Store<any, any> | null;
    _acroFormStore: Store<any, any> | null;
    _panelsUpdateKey: any;
    _pendingBinaryFiles: any;
    private _gcpdfdocumentviewer;
    private pdfUrl;
    _initialViewStateSetFlag: boolean;
    _articlesPanelComponent: Articles.View;
    _stateStorage: GcPdfViewerStateStorage;
    _loadDocViewerPromise: Promise<{}>;
    _cancelledInternal: boolean;
    private _constructed;
    _documentListPanel: PluginModel.PanelHandle;
    private _availablePanelsHash;
    private _licenseErrorShown;
    _pingSupportApiServerTimer: any;
    _supportApiAvailable: boolean;
    private _supportApiPingStarted;
    private _requestId;
    private _updatingAnnotationFlag;
    private _supportApiSuppressError;
    private _supportApiSuppressInfo;
    private _isViewModeSidebarPinned;
    private _updatingPanelFlag;
    _sidebarOpened: boolean;
    private _lastErrorReport;
    private _lastErrorReportTime;
    private _documentAssemblyFlag;
    private _fillingOfFormFieldsFlag;
    _allowPrintFlag: boolean;
    _rightSidebar: GcRightSidebar;
    _editableTextBehavior: GcEditableTextBehavior;
    constructor(_viewer: GcPdfViewer, options: Partial<ViewerOptions>, i18n: i18n);
    applyOptions(): void;
    private _applyOptionsInternal;
    get options(): ViewerOptions;
    set options(options: ViewerOptions);
    get shortcutsConfig(): ShortcutsConfig;
    get docViewer(): any;
    get supportApi(): ISupportApi | null;
    get supportApiEnabled(): boolean;
    _onSupportApiDisconnected(): void;
    _onSupportApiConnected(version: string, isReconnected: boolean): void;
    dispose(): void;
    loadDocumentList(): void;
    reportError(params: PluginModel.IErrorParams): void;
    get hasDocument(): boolean;
    setDocumentListPanel(handle: PluginModel.PanelHandle): void;
    get documentListPanelId(): string | null;
    _onError(event: any): void;
    private _onMouseModeChange;
    private _onAnnotationBoundsChange;
    changeBoundsOrigin(pageIndex: number, bounds: number[], srcOrigin: 'TopLeft' | 'BottomLeft', destOrigin: 'TopLeft' | 'BottomLeft'): number[];
    getViewPort(pageIndex: number): {
        viewBox: number[];
        width: number;
        height: number;
        scale: number;
        rotation: number;
        offsetX: number;
        offsetY: number;
        transform: number[];
    };
    private _onRequestShowCustomLayout;
    private _onRequestHideCustomLayout;
    answerRequest(answerData: any, requestId?: string): void;
    private _onFirstArticleBead;
    _onLastArticleBead(event: any): void;
    _onArticleBeadNavigate(event: any): void;
    _onDocumentClosed(): void;
    _onuUndoStoreChanged(event: any): void;
    ensureSelectedAnnotationElement(pageIndex: number, annotation: AnnotationBase | string, args?: {
        skipPropertiesExpand?: boolean;
    }): Promise<boolean>;
    ensureSelectedAnnotation(): void;
    private _onAnnotationEditStarted;
    _onDocumentOpen(): void;
    private _resetRestrictionFlags;
    private _loadRestrictionFlags;
    private _onPageChange;
    private _onPagesLoaded;
    private _onScaleChange;
    private _activePanelId;
    get activePanelId(): string | null;
    pluginReady(): boolean;
    onPanelChange: (panelId: string | null) => void;
    toggleAnnotationProperties(): void;
    freezeAnnotationEditorButton(): void;
    freezeFormEditorButton(): void;
    toggleFormProperties(): void;
    applyToolbarLayout(): void;
    toggleSidebar(panelId: string, pin?: boolean): void;
    private _onStateChange;
    _updatePanels(state: Model, force?: boolean): void;
    getSelectedText(): string;
    isPanelAvailable(panelId: string): boolean;
    addDocumentTitleTool(): void;
    addOutlinePanel(): void;
    addThumbnailsPanel(): void;
    toggleSearchPanel(): void;
    addSearchPanel(): void;
    addArticlesPanel(): void;
    addAttachmentsPanel(): void;
    get hasReplyTool(): boolean;
    get rightSidebar(): GcRightSidebar;
    addReplyTool(sidebarState?: GcRightSidebarState): void;
    addAnnotationEditorPanel(visible?: boolean): void;
    addFormEditorPanel(visible?: boolean): void;
    addAnnotation(pageIndex: number, annotation: AnnotationBase): Promise<{
        pageIndex: number;
        annotation: AnnotationBase;
    }>;
    updateAnnotation(pageIndex: number, annotation: AnnotationBase): Promise<{
        pageIndex: number;
        annotation: AnnotationBase;
    }>;
    updateAnnotations(pageIndex: number, annotations: AnnotationBase | AnnotationBase[]): Promise<{
        pageIndex: number;
        annotations: AnnotationBase[];
    }>;
    updateRadioGroupValue(fieldName: string, newValue: string, skipPageRefresh?: boolean): Promise<boolean>;
    removeAnnotation(pageIndex: number, annotation: string | AnnotationBase): Promise<boolean>;
    findAnnotation(findString: string | number, findParams?: {
        findField?: 'id' | 'title' | 'contents' | 'fieldName' | string;
        pageNumberConstraint?: number;
        findAll?: boolean;
    }): Promise<{
        pageNumber: number;
        annotation: AnnotationBase;
    }[]>;
    getAttachments(): Promise<{
        pageNumber: number;
        annotation: AnnotationBase;
    }[]>;
    selectAnnotation(pageIndex: number | string, annotation?: AnnotationBase | string): Promise<boolean>;
    setExpandedEditorState(expandedPageIndex: number, selectedAnnotationId: string, expandedAnnotationIds: any): void;
    unselectAnnotation(): any;
    scrollAnnotationIntoView(pageIndex: number, annotation: AnnotationBase): any;
    scrollAnnotationPropertiesIntoView(pageIndex: number, annotation: AnnotationBase | string): void;
    repaint(): void;
    _onAddAnnotationRequest: (pageIndex: number, node: AnnotationBase) => Promise<{
        pageIndex: number;
        annotation: AnnotationBase;
    }>;
    _onUpdateAnnotationRequest: (pageIndex: number, node: AnnotationBase, skipExpand?: boolean) => Promise<{
        pageIndex: number;
        annotation: AnnotationBase;
    }>;
    _onUpdateAnnotationsRequest: (pageIndex: number, nodes: AnnotationBase[]) => Promise<{
        pageIndex: number;
        annotations: AnnotationBase[];
    }>;
    _onRemoveAnnotationRequest: (pageIndex: number, id: string) => Promise<boolean>;
    _onAnnotationNavigate: (pageIndex: number, node: AnnotationBase, params?: {
        preserveExpanded?: boolean | undefined;
        preserveFocused?: boolean | undefined;
        toggle?: boolean | undefined;
    } | undefined) => Promise<void>;
    _updateAttachmentsInternal(force?: boolean): void;
    private _dispatchAnnotationsState;
    _onAnnotationNavigatePage: (pageIndex: number) => Promise<void>;
    loadAndScrollPageIntoView(pageIndex: number, destArray?: any[]): Promise<boolean>;
    get pageIndex(): number;
    get fileData(): Uint8Array | null;
    renderPage(page: PluginModel.IPageData): PluginModel.PageView;
    renderHighlightPage(page: PluginModel.IPageData, results: SearchFeature.SearchResult[]): PluginModel.PageView;
    onEscapePressed(): void;
    onOpenDocument(document: PluginModel.IDocument | null): void;
    loadDocumentTitle(): Promise<void>;
    onOpenDocumentView(view: PluginModel.IDocumentView): void;
    resolveAction(_: any, event: any): PluginModel.ViewerAction | ReportAction | null;
    processAction(context: PluginModel.ActionContext<ReportEvent>, action: ReportAction): boolean;
    get propertiesDialog(): any;
    documentSecurity(): Promise<DocumentSecuritySummary>;
    getDocumentProperties(): Promise<DocumentProperties>;
    get fileUrl(): string;
    get fileName(): string;
    get localFileName(): string;
    showAbout(): void;
    processEvent(context: PluginModel.ActionContext<ReportEvent>, event: ReportEvent, direction: PluginModel.TimeDirection): void;
    openLocalFile(): void;
    rotate(value: any): void;
    beep(): void;
    get scrollViewElement(): HTMLDivElement;
    get hostElement(): HTMLElement;
    goBack(): void;
    goForward(): void;
    cleanupDocument(): void;
    dispatchCommentsState(state?: ReplyToolModel): void;
    openDocument: (moniker: ReportDocumentMoniker) => Promise<PluginModel.IDocument>;
    endUpdate(): void;
    _ensureInitialViewState(): void;
    onBeforeOpenFile(file: any): string;
    open(file: any): void;
    print(): void;
    close(): void;
    save(fileName?: string, saveModificationsOnly?: boolean): Promise<boolean>;
    submitForm(submitUrl: string): void;
    download(fileName?: string): void;
    scrollPageIntoView(params: {
        pageNumber: number;
        destArray?: any[];
        allowNegativeOffset?: boolean;
    }): void;
    scrollBeadIntoView(articleBead: ArticleBead): void;
    isPageVisible(pageNumber: number): boolean;
    language: string;
    get rotation(): number;
    set rotation(val: number);
    currentPageNumber: number;
    updateVisiblePages(): void;
    setTheme(theme?: string): void;
    raiseStateChanged(): void;
    set zoomValue(val: number);
    get zoomValue(): number;
    get hasUndoChanges(): boolean;
    get hasRedoChanges(): boolean;
    get undoIndex(): number;
    get undoCount(): number;
    get annotations(): Promise<{
        pageIndex: number;
        annotations: AnnotationBase[];
    }[]>;
    get version(): string;
    get editMode(): EditMode;
    set editMode(mode: EditMode);
    get layoutMode(): LayoutMode;
    set layoutMode(mode: LayoutMode);
    private _ensureLayoutMode;
    get hideAnnotations(): boolean;
    set hideAnnotations(hide: boolean);
    get hasChanges(): boolean;
    get onError(): EventFan<ErrorEventArgs>;
    get onBeforeOpen(): EventFan<BeforeOpenEventArgs>;
    get onAfterOpen(): EventFan<AfterOpenEventArgs>;
    toViewPortPoint(p: GcSelectionPoint): GcSelectionPoint;
    addStickyNote(position: GcSelectionPoint): void;
    showInlineTextEditor(textElement: HTMLElement, annotationElement: HTMLElement, pageIndex: number, annotation: AnnotationBase, propertyKey: string): void;
    hideInlineTextEditor(): void;
    cloneAnnotation(annotation: AnnotationBase): AnnotationBase;
    get hasCopyData(): boolean;
    execCutAction(buffer?: CopyBufferData): Promise<boolean>;
    execCopyAction(buffer?: CopyBufferData): Promise<boolean>;
    execPasteAction(position?: GcSelectionPoint): Promise<boolean>;
    execDeleteAction(buffer?: CopyBufferData): Promise<boolean>;
    setAnnotationState(pageIndex: number, referenceAnnotation: TextAnnotation, state: AnnotationMarkedStateType | AnnotationReviewStateType, referenceType: 'R' | 'Group', userName?: string): Promise<boolean>;
    undoChanges(): void;
    redoChanges(): void;
    newDocument(params?: {
        fileName?: string;
        confirm?: boolean;
    }): Promise<LoadResult | null>;
    newPage(params?: {
        width?: number;
        height?: number;
        pageIndex?: number;
    }): void;
    deletePage(pageIndex?: number): void;
    private _leftSidebarWidths;
    private _leftSideBarResizedHandler;
    private _setInitialLeftSidebarWidth;
    private _freezePanelButtonActiveState;
    private _unfreezePanelButtonActiveState;
    private _updateEditorToolbarLayout;
    private _createEditorStore;
    private _loadDocViewer;
    get searcher(): GcPdfSearcher;
    private _onDocViewerReady;
    private _showLicenseError;
    get sidebarPinned(): boolean;
    execSidebarPanel(methodName: 'pin' | 'open' | 'unpin' | 'close' | 'toggle' | 'collapse' | 'expand', panelId?: string): void;
    _ensureEditorCloseIcon(): void;
    private _showEditorPanel;
    get fingerprint(): string;
    private _editorRestrictionsMessageShownKey;
    private _showEditorRestrictionsIfAny;
    private _showViewerLayout;
    private _onAnnotationLoaded;
    get currentUserName(): string;
    set currentUserName(userName: string);
    updateTextCommentsState(annotationsData: {
        pageIndex: number;
        annotations: AnnotationBase[];
    }[]): void;
    private _appendAttachment;
    private onArticleNavigate;
    private onAttachmentNavigate;
    private onPdfAttachmentNavigate;
    private onNavigate;
    private _updateDocumentTitle;
    private _ensureDocTitleClass;
    get documentOpenedOnServer(): boolean;
    get canEditDocument(): boolean;
    get canPrintDocument(): boolean;
    get canAddStickyNote(): boolean;
    _additionalLocalizationMessages(): void;
    showEditingToolsDisabledMessage(details?: string, severity?: "error" | "warn" | "info" | "debug"): void;
    private _pingSupportApiServer;
    private _convertPropertyValues;
}
export declare function HideAnnotationsButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function DownloadButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function SaveButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function NewDocumentButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function NewPageButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function DeletePageButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function PrintButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function RotateButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function OpenButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function TextSelectionButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function PanButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function FreeTextAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function TextAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function InkAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function SquareAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function LineAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function CircleAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function PolylineAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function PolygonAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function FileAttachmentAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function SoundAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function LinkAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function ApplyRedactButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function RedactButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function SelectAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function SelectFieldButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function TextFieldWidgetButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function CombTextFieldWidgetButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function PasswordFieldWidgetButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function TextAreaWidgetButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function CheckBoxWidgetButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function RadioWidgetButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function PushWidgetButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function SubmitWidgetButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function ResetWidgetButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function ComboChoiceWidgetButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function ListBoxChoiceWidgetButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function EraseAnnotationButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function EraseFieldButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function ShowEditToolsButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function ShowFormEditorButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function ToggleAnnotationPropertiesButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function ToggleFormPropertiesButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function ShowViewToolsButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function UndoChangesButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function RedoChangesButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function ConfirmOkButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function ConfirmCancelButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function DocPropertiesButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare function AboutButton(viewer: GcPdfViewer, shortcutTip?: string): ToolbarItem;
export declare let confirmationDialog: ConfirmationDialog;
export declare let inputPassword: GcPdfPasswordDialog;
export declare let printProgress: any;
export declare let fPropertiesDialog: any;
export declare let progressDialog: ProgressDialog;
export declare let contextMenuProvider: ContextMenuProvider;
export default PdfReportPlugin;
